package com.zd.laboratory.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import com.zd.common.core.domain.per.PerFun;
import com.zd.common.core.domain.per.PerPrefix;
import com.zd.common.core.web.domain.AjaxResult;
import com.zd.common.core.web.domain.ResultData;
import com.zd.laboratory.domain.vo.LabSecurityMaterialVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zd.common.log.annotation.Log;
import com.zd.common.log.enums.BusinessType;
import com.zd.common.security.annotation.PreAuthorize;
import com.zd.laboratory.domain.LabSecurityMaterial;
import com.zd.laboratory.service.ILabSecurityMaterialService;
import com.zd.common.core.web.controller.BaseController;
import com.zd.common.core.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

import com.zd.common.core.web.page.TableDataInfo;

/**
 * 安全准入资格材料Controller
 *
 * @author zd
 * @date 2021-09-10
 */
@RestController
@Api(tags = "【安全准入资格材料】")
@RequestMapping("/material")
public class LabSecurityMaterialController extends BaseController {
    @Autowired
    private ILabSecurityMaterialService labSecurityMaterialService;

    /**
     * 查询安全准入资格材料列表
     */
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_MATERIAL + PerFun.LIST)
    @GetMapping("/list")
    @ApiOperation(value = "查询安全准入资格材料列表")
    public TableDataInfo<LabSecurityMaterial> list(LabSecurityMaterial labSecurityMaterial) {
        startPage();
        List<LabSecurityMaterial> list = labSecurityMaterialService.selectLabSecurityMaterialList(labSecurityMaterial);
        return getDataTable(list);
    }

    /**
     * 导出安全准入资格材料列表
     */
    @ApiOperation(value = "导出安全准入资格材料列表")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_MATERIAL + PerFun.EXPORT)
    @Log(title = "安全准入资格材料", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, LabSecurityMaterial labSecurityMaterial) throws IOException {
        List<LabSecurityMaterial> list = labSecurityMaterialService.selectLabSecurityMaterialList(labSecurityMaterial);
        ExcelUtil<LabSecurityMaterial> util = new ExcelUtil<LabSecurityMaterial>(LabSecurityMaterial.class);
        util.exportExcel(response, list, "安全准入资格材料数据");
    }

    /**
     * 获取安全准入资格材料详细信息
     */
    @ApiOperation(value = "获取安全准入资格材料详细信息")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_MATERIAL + PerFun.QUERY)
    @GetMapping(value = "/{id}")
    public ResultData<LabSecurityMaterial> getInfo(@PathVariable("id") Long id) {
        return ResultData.success(labSecurityMaterialService.selectLabSecurityMaterialById(id));
    }

    /**
     * 新增安全准入资格材料
     */
    @ApiOperation(value = "新增安全准入资格材料")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_MATERIAL + PerFun.ADD)
    @Log(title = "安全准入资格材料", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultData add(@RequestBody LabSecurityMaterial labSecurityMaterial) {
        return ResultData.result(labSecurityMaterialService.insertLabSecurityMaterial(labSecurityMaterial));
    }

    /**
     * 修改安全准入资格材料
     */
    @ApiOperation(value = "修改安全准入资格材料")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_MATERIAL + PerFun.EDIT)
    @Log(title = "安全准入资格材料", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultData edit(@RequestBody LabSecurityMaterial labSecurityMaterial) {
        return ResultData.result(labSecurityMaterialService.updateLabSecurityMaterial(labSecurityMaterial));
    }

    /**
     * 删除安全准入资格材料
     */
    @ApiOperation(value = "删除安全准入资格材料")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_MATERIAL + PerFun.REMOVE)
    @Log(title = "安全准入资格材料", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public ResultData remove(@PathVariable Long[] ids) {
        return ResultData.result(labSecurityMaterialService.deleteLabSecurityMaterialByIds(ids));
    }


    /**
     * 查询实验室下的安全准入资格材料列表（小程序）
     */
    @RequestMapping("/subjectMaterialList")
    @ApiOperation(value = "查询实验室下的安全准入资格材料列表")
    public AjaxResult subjectMaterialList(@RequestBody LabSecurityMaterialVO labSecurityMaterial) {
        List<LabSecurityMaterialVO> list = labSecurityMaterialService.subjectMaterialList(labSecurityMaterial);
        return AjaxResult.success(list);
    }
}
